package org.ow2.easybeans.deployment.annotations.analyzer.configurator.metadata.ejbjar;

import org.ow2.easybeans.deployment.annotations.analyzer.configurator.metadata.CommonMethodMetadataConfigurator;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.JavaxAnnotationSecurityPermitAllVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.JavaxAnnotationSecurityRolesAllowedVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.JavaxEjbTransactionAttributeVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.JavaxInterceptorExcludeDefaultInterceptorsVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.JavaxInterceptorInterceptorsVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.method.JavaxAnnotationPostConstructVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.method.JavaxAnnotationPreDestroyVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.method.JavaxAnnotationSecurityDenyAllVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.method.JavaxEjbInitVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.method.JavaxEjbPostActivateVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.method.JavaxEjbPrePassivateVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.method.JavaxEjbRemoveVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.method.JavaxEjbTimeoutVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.method.JavaxInterceptorAroundInvokeVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.method.JavaxInterceptorExcludeClassInterceptorsVisitor;
import org.ow2.easybeans.deployment.metadata.ejbjar.EjbJarClassMetadata;
import org.ow2.easybeans.deployment.metadata.ejbjar.EjbJarFieldMetadata;
import org.ow2.easybeans.deployment.metadata.ejbjar.EjbJarMethodMetadata;
import org.ow2.util.scan.api.metadata.structures.JMethod;

/**
 * EjbJarMethodMetadataConfigurator.
 * @author Gael Lalire
 */
public class EjbJarMethodMetadataConfigurator extends
        CommonMethodMetadataConfigurator<EjbJarClassMetadata, EjbJarMethodMetadata, EjbJarFieldMetadata> {

    /**
     * Constructor.
     * @param jMethod signature
     * @param classMetadata parent
     * @param annotationParsingDesactived annotationParsingDesactived
     */
    public EjbJarMethodMetadataConfigurator(final JMethod jMethod, final EjbJarClassMetadata classMetadata,
            final boolean annotationParsingDesactived) {
        super(new EjbJarMethodMetadata(jMethod, classMetadata));

        if (!annotationParsingDesactived) {
            registerAnnotationVisitor();
        }

    }


    /**
     * register annotation visitor.
     */
    @Override
    protected void registerAnnotationVisitor() {

        super.registerAnnotationVisitor();

        EjbJarMethodMetadata ejbJarMethodMetadata = getMethodMetadata();

        // add @Init
        getAnnotationVisitors().put(JavaxEjbInitVisitor.TYPE, new JavaxEjbInitVisitor(ejbJarMethodMetadata));

        // add @Remove
        getAnnotationVisitors().put(JavaxEjbRemoveVisitor.TYPE, new JavaxEjbRemoveVisitor(ejbJarMethodMetadata));

        // add @TransactionAttribute
        getAnnotationVisitors().put(JavaxEjbTransactionAttributeVisitor.TYPE,
                new JavaxEjbTransactionAttributeVisitor<EjbJarMethodMetadata>(ejbJarMethodMetadata));

        // add @PostConstruct
        getAnnotationVisitors().put(JavaxAnnotationPostConstructVisitor.TYPE,
                new JavaxAnnotationPostConstructVisitor(ejbJarMethodMetadata));
        // add @PreDestroy
        getAnnotationVisitors().put(JavaxAnnotationPreDestroyVisitor.TYPE,
                new JavaxAnnotationPreDestroyVisitor(ejbJarMethodMetadata));
        // add @PostActivate
        getAnnotationVisitors().put(JavaxEjbPostActivateVisitor.TYPE, new JavaxEjbPostActivateVisitor(ejbJarMethodMetadata));
        // add @PrePassivate
        getAnnotationVisitors().put(JavaxEjbPrePassivateVisitor.TYPE, new JavaxEjbPrePassivateVisitor(ejbJarMethodMetadata));

        // add @Timeout
        getAnnotationVisitors().put(JavaxEjbTimeoutVisitor.TYPE, new JavaxEjbTimeoutVisitor(ejbJarMethodMetadata));

        // add @AroundInvoke
        getAnnotationVisitors().put(JavaxInterceptorAroundInvokeVisitor.TYPE,
                new JavaxInterceptorAroundInvokeVisitor(ejbJarMethodMetadata));

        // add @Interceptors
        getAnnotationVisitors().put(JavaxInterceptorInterceptorsVisitor.TYPE,
                new JavaxInterceptorInterceptorsVisitor<EjbJarMethodMetadata>(ejbJarMethodMetadata));

        // add @ExcludeClassInterceptors
        getAnnotationVisitors().put(JavaxInterceptorExcludeClassInterceptorsVisitor.TYPE,
                new JavaxInterceptorExcludeClassInterceptorsVisitor(ejbJarMethodMetadata));

        // add @RolesAllowed
        getAnnotationVisitors().put(JavaxAnnotationSecurityRolesAllowedVisitor.TYPE,
                new JavaxAnnotationSecurityRolesAllowedVisitor<EjbJarMethodMetadata>(ejbJarMethodMetadata));

        // add @PermitAll
        getAnnotationVisitors().put(JavaxAnnotationSecurityPermitAllVisitor.TYPE,
                new JavaxAnnotationSecurityPermitAllVisitor<EjbJarMethodMetadata>(ejbJarMethodMetadata));

        // add @DenyAll
        getAnnotationVisitors().put(JavaxAnnotationSecurityDenyAllVisitor.TYPE,
                new JavaxAnnotationSecurityDenyAllVisitor(ejbJarMethodMetadata));

        // add @ExcludeDefaultInterceptors
        getAnnotationVisitors().put(JavaxInterceptorExcludeDefaultInterceptorsVisitor.TYPE,
                new JavaxInterceptorExcludeDefaultInterceptorsVisitor<EjbJarMethodMetadata>(ejbJarMethodMetadata));

    }


}
