/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: AbsDeploymentDescLoader.java 2054 2007-11-20 14:43:55Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.xml.parsing;

import java.net.URL;

import org.w3c.dom.Element;

/**
 * Common stuff for parsing XML files.
 * @author Florent BENOIT
 */
public abstract class AbsDeploymentDescLoader {

    /**
     * Java EE namespace (Java EE).
     */
    public static final String JAVAEE_NS = "http://java.sun.com/xml/ns/javaee";

    /**
     * J2EE namespace (J2EE).
     */
    public static final String J2EE_NS = "http://java.sun.com/xml/ns/j2ee";

    /**
     * Validating with schema ?
     */
    private static boolean validating = true;

    /**
     * URL of the file being analyzed.
     */
    private URL url = null;

    /**
     * Namespace to use when analyzing the XML file. It depends if the archive is J2EE or Java EE module.
     */
    private String xmlns = null;

    /**
    * Create a new Desc Loader for the given URL.
     * @param url the url that is pointing to the EJB Xml file.
     */
    protected AbsDeploymentDescLoader(final URL url) {
        this.url = url;
    }

    /**
     * @return the URL used by this loader.
     */
    protected URL getURL() {
        return url;
    }

    /**
     * @return true if the deployment is being validated.
     */
    public static boolean isValidating() {
        return validating;
    }

    /**
     * Defines the namespace that needs to be used for this XML parsing.
     * @param element the DOM element used to get the namespace.
     * @throws ParsingException if no namespace is found
     */
    protected void defineXMLNS(final Element element) throws ParsingException {
        // get the namespace of this element
        String ns = element.getNamespaceURI();
        if (JAVAEE_NS.equals(ns)) {
            this.xmlns = JAVAEE_NS;
        } else if (J2EE_NS.equals(ns)) {
            this.xmlns = J2EE_NS;
        } else {
            throw new ParsingException("Unsupported XML namespace: " + ns);
        }
    }

    /**
     * @return the Namespace to use when analyzing the XML file.
     */
    protected String getXMLNS() {
        return xmlns;
    }

}
